summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorAndrey Kleshchev <andreykproductengine@lindenlab.com>2020-04-03 19:40:55 +0300
committerAndrey Kleshchev <andreykproductengine@lindenlab.com>2020-04-03 19:40:55 +0300
commit29fec00f3c434d5aa9586de8ae88c4cd247689a7 (patch)
treec7ccca244f86d15e84d636d2822f09e207817846
parent6e8971c4b8c277994fea9c09624cce687c4e36f1 (diff)
SL-12775 Run at high performance AMD gpu
-rw-r--r--indra/llrender/llgl.cpp7
1 files changed, 4 insertions, 3 deletions
diff --git a/indra/llrender/llgl.cpp b/indra/llrender/llgl.cpp
index c0f0cec80b..2b09a0b090 100644
--- a/indra/llrender/llgl.cpp
+++ b/indra/llrender/llgl.cpp
@@ -2562,10 +2562,11 @@ void LLGLSyncFence::wait()
}
#if LL_WINDOWS
// Expose desired use of high-performance graphics processor to Optimus driver
extern "C"
-{
- _declspec(dllexport) DWORD NvOptimusEnablement = 0x00000001;
+{
+ __declspec(dllexport) DWORD NvOptimusEnablement = 0x00000001;
+ __declspec(dllexport) int AmdPowerXpressRequestHighPerformance = 1;
}
#endif
@@ -2562,10 +2562,11 @@ void LLGLSyncFence::wait()
}
#if LL_WINDOWS
-// Expose desired use of high-performance graphics processor to Optimus driver
+// Expose desired use of high-performance graphics processor to Optimus driver and to AMD driver
extern "C"